@@ -23,6 +23,10 @@
   * @author Michael Zanetti
   */
 
+#if defined(HAVE_CONFIG_H)
+#include "config.h"
+#endif
+
 #include <tqapplication.h>
 #include <tqeventloop.h>
 
@@ -83,7 +87,7 @@ bool OtrlConfInterface::hasPrivFingerprint( TQString accountId, TQString protoco
 
 
 void OtrlConfInterface::generateNewPrivKey( TQString accountId, TQString protocol ){
-	PrivKeyPopup *popup = new PrivKeyPopup( preferencesDialog, i18n("Generating private key"),  TQt::WStyle_Dialog | TQt::WStyle_StaysOnTop );
+	PrivKeyPopup *popup = new PrivKeyPopup( preferencesDialog, i18n("Generating private key").utf8(), TQt::WType_Dialog | TQt::WStyle_StaysOnTop );
 	KAnimWidget *anim = new KAnimWidget( "kde", 72, popup->animFrame, "kopete" );
 	anim->start();
 	anim->show();
@@ -99,37 +103,38 @@ void OtrlConfInterface::generateNewPrivKey( TQString accountId, TQString protoco
 	popup->close();
 }
 
-TQValueList<TQString[5]> OtrlConfInterface::readAllFingerprints(){
+TQValueList<TQStringList> OtrlConfInterface::readAllFingerprints(){
 	ConnContext *context;
 	Fingerprint *fingerprint;
-	TQString entry[5];
+	TQStringList entry;
 	char hash[45];
-	TQValueList<TQString[5]> list;
+	TQValueList<TQStringList> list;
 
 	for( context = userstate->context_root; context != NULL; context = context->next ){
 		fingerprint = context->fingerprint_root.next;
 		while( fingerprint ){
-			entry[0] = context->username;
+			entry.clear();
+			entry << context->username;
 
 			if( ( context->msgstate == OTRL_MSGSTATE_ENCRYPTED ) && ( context->active_fingerprint != fingerprint ) ){
-				entry[1] = i18n("Unused");
+				entry << i18n("Unused");
 			} else {
 				if (context && context->msgstate == OTRL_MSGSTATE_ENCRYPTED) {
-					if (context->active_fingerprint->trust && context->active_fingerprint->trust[0] != NULL) {
-						entry[1] = i18n("Private");
+					if (context->active_fingerprint->trust && context->active_fingerprint->trust[0] != 0) {
+						entry << i18n("Private");
 					} else {
-						entry[1] = i18n("Unverified");
+						entry << i18n("Unverified");
 					}
 				} else if (context && context->msgstate == OTRL_MSGSTATE_FINISHED) {
-					entry[1] = i18n("Finished");
+					entry << i18n("Finished");
 				} else {
-					entry[1] = i18n("Not Private");
+					entry << i18n("Not Private");
 				}
 			}
-			entry[2] = ( fingerprint->trust && fingerprint->trust[0] ) ? i18n("Yes") : i18n("No") ;
+			entry << ((fingerprint->trust && fingerprint->trust[0]) ? i18n("Yes") : i18n("No"));
 			otrl_privkey_hash_to_human( hash, fingerprint->fingerprint );
-			entry[3] = hash;
-			entry[4] = context->protocol;
+			entry << hash;
+			entry << context->protocol;
 			list << entry;
 			fingerprint = fingerprint->next;
 		}
@@ -149,7 +154,7 @@ void OtrlConfInterface::verifyFingerprint( TQString strFingerprint, bool trust )
 			otrl_context_set_trust( fingerprint, NULL );
 		}
 		kdDebug() << "Writing fingerprints" << endl;
-		otrl_privkey_write_fingerprints( userstate, TQString(TDEGlobal::dirs()->saveLocation("data", "kopete_otr/", true )) + "fingerprints" );
+		otrl_privkey_write_fingerprints( userstate, TQString("%1%2").arg(TDEGlobal::dirs()->saveLocation("data", "kopete_otr/", true )).arg("fingerprints").local8Bit() );
 	} else {
 		kdDebug() << "could not find fingerprint" << endl;
 	}
@@ -158,7 +163,7 @@ void OtrlConfInterface::verifyFingerprint( TQString strFingerprint, bool trust )
 bool OtrlConfInterface::isVerified( TQString strFingerprint ){
 	Fingerprint *fingerprint;	
 
-	fingerprint = findFingerprint( strFingerprint );
+	fingerprint = findFingerprint( strFingerprint.latin1() );
 
 	if( fingerprint->trust && fingerprint->trust[0] ){
 		kdDebug() << "found trust" << endl;
@@ -175,7 +180,7 @@ void OtrlConfInterface::forgetFingerprint( TQString strFingerprint ){
 	
 	fingerprint = findFingerprint( strFingerprint );
 	otrl_context_forget_fingerprint( fingerprint, 1 );
-	otrl_privkey_write_fingerprints( userstate, TQString(TDEGlobal::dirs()->saveLocation("data", "kopete_otr/", true )) + "fingerprints" );
+	otrl_privkey_write_fingerprints( userstate, TQString("%1%2").arg(TDEGlobal::dirs()->saveLocation("data", "kopete_otr/", true )).arg("fingerprints").local8Bit() );
 }
 
 Fingerprint *OtrlConfInterface::findFingerprint( TQString strFingerprint ){
