@@ -18,13 +18,17 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
-#include "tqlabel.h"
+#if defined(HAVE_CONFIG_H)
+#include "config.h"
+#endif
 
-#include "kdebug.h"
-#include "tdelocale.h"
-#include "klineedit.h"
-#include "kurl.h"
-#include "krun.h"
+#include <tqlabel.h>
+
+#include <kdebug.h>
+#include <tdelocale.h>
+#include <klineedit.h>
+#include <kurl.h>
+#include <krun.h>
 
 #include "smppopup.h"
 #include "verifypopup.h"
@@ -74,7 +78,7 @@ void SMPPopup::openHelp()
 }
 
 void SMPPopup::manualAuth(){
-	VerifyPopup *vfPopup = new VerifyPopup(this, i18n("Verify Fingerprint"), session);
+	VerifyPopup *vfPopup = new VerifyPopup(this, i18n("Verify Fingerprint").utf8(), session);
 	vfPopup->show();
 	this->close();
 }
