@@ -18,6 +18,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
+#if defined(HAVE_CONFIG_H)
+#include "config.h"
+#endif
 
 #include "verifypopup.h"
 #include "otrlchatinterface.h"
